@@ -13,18 +13,14 @@ ARGS = [
 ]
 
 
-def compile_solution(directory, mode):
-    if mode != 'auto':
-        click.secho(f'Unknown run mode {mode}', fg='yellow', err=True)
-        return None
-
+def compile_solution(directory):
     c_files = list(directory.glob('*.c'))
 
     if len(c_files) == 0:
         click.secho('No .c files found', fg='yellow', err=True)
         return None
 
-    click.secho('Compiling...', fg='green', err=True)
+    click.secho('Compiling... ', fg='green', err=True, nl=False)
 
     binary = compile_c(directory, c_files)
 
